@@ -11,7 +11,7 @@ use TheSchwartz::Moosified::Utils qw/insert_id sql_for_unixtime bind_param_attr
 use TheSchwartz::Moosified::Job;
 use TheSchwartz::Moosified::JobHandle;
 
-our $VERSION = '0.06'; # when bumping, also update t/00-load.t
+our $VERSION = '0.07'; # when bumping, also update t/00-load.t
 our $AUTHORITY = 'cpan:FAYLAND';
 
 ## Number of jobs to fetch at a time in find_job_for_workers.
@@ -177,8 +177,7 @@ sub find_job_for_workers {
             my $sth = $dbh->prepare_cached($sql);
             $sth->execute();
             while ( my $ref = $sth->fetchrow_hashref ) {
-                my $job = TheSchwartz::Moosified::Job->new( $ref );
-                push @jobs, $job;
+                push @jobs, $ref;
             }
             $sth->finish;
         };
@@ -204,7 +203,9 @@ sub _grab_a_job {
     @jobs = shuffle(@jobs);
 
   JOB:
-    while (my $job = shift @jobs) {
+    while (my $ref = shift @jobs) {
+        my $job = TheSchwartz::Moosified::Job->new( $ref );
+
         ## Convert the funcid to a funcname, based on this database's map.
         $job->funcname( $client->funcid_to_name($dbh, $job->funcid) );
 
@@ -358,8 +359,7 @@ sub _find_job_with_coalescing {
             $sth->execute( $funcid, $coval );
             while ( my $ref = $sth->fetchrow_hashref ) {
                 $ref->{funcname} = $funcname;
-                my $job = TheSchwartz::Moosified::Job->new( $ref );
-                push @jobs, $job;
+                push @jobs, $ref;
             }
             $sth->finish;
         };
@@ -792,9 +792,11 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 
 Jeremy Stashewsky, C<< <jstash+cpan at gmail.com> >>
 
+Luke Closs C<< <cpan at 5thplane.com> >>
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Fayland Lam, all rights reserved.
+Copyright 2008,2016 Fayland Lam, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
