@@ -11,7 +11,8 @@ sub job {
     my $handle = shift;
     
     my $dbh = $handle->dbh;
-    my $sql = qq~SELECT * FROM job WHERE jobid = ?~;
+    my $table_job = $handle->client->prefix . 'job';
+    my $sql = qq~SELECT * FROM $table_job WHERE jobid = ?~;
     my $sth = $dbh->prepare_cached($sql);
     $sth->execute($handle->jobid);
     my $row = $sth->fetchrow_hashref;
@@ -32,7 +33,8 @@ sub exit_status {
     my $handle = shift;
     
     my $dbh = $handle->dbh;
-    my $sql = q~SELECT status FROM exitstatus WHERE jobid = ?~;
+    my $table_exitstatus = $handle->client->prefix . 'exitstatus';
+    my $sql = qq~SELECT status FROM $table_exitstatus WHERE jobid = ?~;
     my $sth = $dbh->prepare($sql);
     $sth->execute($handle->jobid);
     my ($status) = $sth->fetchrow_array;
@@ -43,7 +45,8 @@ sub failure_log {
     my $handle = shift;
     
     my $dbh = $handle->dbh;
-    my $sql = q~SELECT message FROM error WHERE jobid = ?~;
+    my $table_error = $handle->client->prefix . 'error';
+    my $sql = qq~SELECT message FROM $table_error WHERE jobid = ?~;
     my $sth = $dbh->prepare($sql);
     $sth->execute($handle->jobid);
     
